Maximum a posteriori purified profiles under a Gaussian convolution
Source:R/03_04_DeCovarT_estimate_CTS_MAP_Bayesian.R
dot-map_gaussian_convolution.RdFor fixed plug-in \(\boldsymbol{\zeta}=(\boldsymbol{\mu},\{\boldsymbol{\Sigma}_j\})\) and a bulk vector \(\boldsymbol{y}\), returns cell-type-specific MAP estimates of the latent purified profiles \(\boldsymbol{x}_{\cdot j}\) in the additive Gaussian model of the article. This is the Bayesian counterpart to the frequentist plug-in that replaces \(\boldsymbol{x}_{\cdot j}\) by \(\boldsymbol{\mu}_{\cdot j}\) when estimating proportions alone.